@@ -14,23 +14,56 @@ CONF = config.CONF
 
 
 @click.group()
-@click.option('--debug', default=False, is_flag=True,
-              help="Output more information about what's going on.")
-@click.option('--token', metavar='TOKEN', envvar='PW_TOKEN',
-              help="Authentication token. Defaults to the value of "
-              "'git config pw.token'.")
-@click.option('--username', metavar='USERNAME', envvar='PW_USERNAME',
-              help="Authentication username. Defaults to the value of "
-              "'git config pw.username'.")
-@click.option('--password', metavar='PASSWORD', envvar='PW_PASSWORD',
-              help="Authentication password. Defaults to the value of "
-              "'git config pw.password'.")
-@click.option('--server', metavar='SERVER', envvar='PW_SERVER',
-              help="Patchwork server address/hostname. Defaults to the value "
-              "of 'git config pw.server'.")
-@click.option('--project', metavar='PROJECT', envvar='PW_PROJECT',
-              help="Patchwork project. Defaults the value of "
-              "'git config pw.project'.")
+@click.option(
+    '--debug',
+    default=False,
+    is_flag=True,
+    help="Output more information about what's going on.",
+)
+@click.option(
+    '--token',
+    metavar='TOKEN',
+    envvar='PW_TOKEN',
+    help=(
+        "Authentication token. "
+        "Defaults to the value of 'git config pw.token'."
+    ),
+)
+@click.option(
+    '--username',
+    metavar='USERNAME',
+    envvar='PW_USERNAME',
+    help=(
+        "Authentication username. "
+        "Defaults to the value of 'git config pw.username'."
+    ),
+)
+@click.option(
+    '--password',
+    metavar='PASSWORD',
+    envvar='PW_PASSWORD',
+    help=(
+        "Authentication password. "
+        "Defaults to the value of 'git config pw.password'."
+    ),
+)
+@click.option(
+    '--server',
+    metavar='SERVER',
+    envvar='PW_SERVER',
+    help=(
+        "Patchwork server address/hostname. "
+        "Defaults to the value of 'git config pw.server'."
+    ),
+)
+@click.option(
+    '--project',
+    metavar='PROJECT',
+    envvar='PW_PROJECT',
+    help=(
+        "Patchwork project. Defaults to the value of 'git config pw.project'."
+    ),
+)
 @click.version_option()
 def cli(debug, token, username, password, server, project):
     """git-pw is a tool for integrating Git with Patchwork.
